# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Required, TypedDict

__all__ = ["ObservationQueryParams"]


class ObservationQueryParams(TypedDict, total=False):
    query: Required[str]
    """Semantic search query"""

    distance: Optional[float]
    """Maximum cosine distance threshold for results"""

    filters: Optional[Dict[str, object]]
    """Additional filters to apply"""

    top_k: int
    """Number of results to return"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["PeerCardConfigurationParam"]


class PeerCardConfigurationParam(TypedDict, total=False):
    create: Optional[bool]
    """Whether to generate peer card based on content."""

    use: Optional[bool]
    """Whether to use peer card related to this peer during deriver process."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["WebhookEndpoint"]


class WebhookEndpoint(BaseModel):
    id: str

    created_at: datetime

    url: str

    workspace_id: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable, Optional

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncPage, AsyncPage
from ..._base_client import AsyncPaginator, make_request_options
from ...types.workspaces import conclusion_list_params, conclusion_query_params, conclusion_create_params
from ...types.workspaces.conclusion import Conclusion
from ...types.workspaces.conclusion_create_param import ConclusionCreateParam
from ...types.workspaces.conclusion_query_response import ConclusionQueryResponse
from ...types.workspaces.conclusion_create_response import ConclusionCreateResponse

__all__ = ["ConclusionsResource", "AsyncConclusionsResource"]


class ConclusionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ConclusionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/plastic-labs/honcho-python-core#accessing-raw-response-data-eg-headers
        """
        return ConclusionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ConclusionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/plastic-labs/honcho-python-core#with_streaming_response
        """
        return ConclusionsResourceWithStreamingResponse(self)

    def create(
        self,
        workspace_id: str,
        *,
        conclusions: Iterable[ConclusionCreateParam],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConclusionCreateResponse:
        """
        Create one or more conclusions.

        Conclusions are theory-of-mind facts derived from interactions between peers.

        Args:
          workspace_id: ID of the workspace

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return self._post(
            f"/v2/workspaces/{workspace_id}/conclusions",
            body=maybe_transform({"conclusions": conclusions}, conclusion_create_params.ConclusionCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConclusionCreateResponse,
        )

    def list(
        self,
        workspace_id: str,
        *,
        page: int | Omit = omit,
        reverse: Optional[bool] | Omit = omit,
        size: int | Omit = omit,
        filters: Optional[Dict[str, object]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncPage[Conclusion]:
        """
        List conclusions using custom filters, ordered by recency unless `reverse` is
        true.

        Args:
          workspace_id: ID of the workspace

          page: Page number

          reverse: Whether to reverse the order of results

          size: Page size

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return self._get_api_list(
            f"/v2/workspaces/{workspace_id}/conclusions/list",
            page=SyncPage[Conclusion],
            body=maybe_transform({"filters": filters}, conclusion_list_params.ConclusionListParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "reverse": reverse,
                        "size": size,
                    },
                    conclusion_list_params.ConclusionListParams,
                ),
            ),
            model=Conclusion,
            method="post",
        )

    def delete(
        self,
        conclusion_id: str,
        *,
        workspace_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Delete a specific conclusion (document).

        Args:
          workspace_id: ID of the workspace

          conclusion_id: ID of the conclusion to delete

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        if not conclusion_id:
            raise ValueError(f"Expected a non-empty value for `conclusion_id` but received {conclusion_id!r}")
        return self._delete(
            f"/v2/workspaces/{workspace_id}/conclusions/{conclusion_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def query(
        self,
        workspace_id: str,
        *,
        query: str,
        distance: Optional[float] | Omit = omit,
        filters: Optional[Dict[str, object]] | Omit = omit,
        top_k: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConclusionQueryResponse:
        """
        Query conclusions using semantic search.

        Args:
          workspace_id: ID of the workspace

          query: Semantic search query

          distance: Maximum cosine distance threshold for results

          filters: Additional filters to apply

          top_k: Number of results to return

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return self._post(
            f"/v2/workspaces/{workspace_id}/conclusions/query",
            body=maybe_transform(
                {
                    "query": query,
                    "distance": distance,
                    "filters": filters,
                    "top_k": top_k,
                },
                conclusion_query_params.ConclusionQueryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConclusionQueryResponse,
        )


class AsyncConclusionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncConclusionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/plastic-labs/honcho-python-core#accessing-raw-response-data-eg-headers
        """
        return AsyncConclusionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncConclusionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/plastic-labs/honcho-python-core#with_streaming_response
        """
        return AsyncConclusionsResourceWithStreamingResponse(self)

    async def create(
        self,
        workspace_id: str,
        *,
        conclusions: Iterable[ConclusionCreateParam],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConclusionCreateResponse:
        """
        Create one or more conclusions.

        Conclusions are theory-of-mind facts derived from interactions between peers.

        Args:
          workspace_id: ID of the workspace

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return await self._post(
            f"/v2/workspaces/{workspace_id}/conclusions",
            body=await async_maybe_transform(
                {"conclusions": conclusions}, conclusion_create_params.ConclusionCreateParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConclusionCreateResponse,
        )

    def list(
        self,
        workspace_id: str,
        *,
        page: int | Omit = omit,
        reverse: Optional[bool] | Omit = omit,
        size: int | Omit = omit,
        filters: Optional[Dict[str, object]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[Conclusion, AsyncPage[Conclusion]]:
        """
        List conclusions using custom filters, ordered by recency unless `reverse` is
        true.

        Args:
          workspace_id: ID of the workspace

          page: Page number

          reverse: Whether to reverse the order of results

          size: Page size

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return self._get_api_list(
            f"/v2/workspaces/{workspace_id}/conclusions/list",
            page=AsyncPage[Conclusion],
            body=maybe_transform({"filters": filters}, conclusion_list_params.ConclusionListParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "reverse": reverse,
                        "size": size,
                    },
                    conclusion_list_params.ConclusionListParams,
                ),
            ),
            model=Conclusion,
            method="post",
        )

    async def delete(
        self,
        conclusion_id: str,
        *,
        workspace_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Delete a specific conclusion (document).

        Args:
          workspace_id: ID of the workspace

          conclusion_id: ID of the conclusion to delete

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        if not conclusion_id:
            raise ValueError(f"Expected a non-empty value for `conclusion_id` but received {conclusion_id!r}")
        return await self._delete(
            f"/v2/workspaces/{workspace_id}/conclusions/{conclusion_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def query(
        self,
        workspace_id: str,
        *,
        query: str,
        distance: Optional[float] | Omit = omit,
        filters: Optional[Dict[str, object]] | Omit = omit,
        top_k: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ConclusionQueryResponse:
        """
        Query conclusions using semantic search.

        Args:
          workspace_id: ID of the workspace

          query: Semantic search query

          distance: Maximum cosine distance threshold for results

          filters: Additional filters to apply

          top_k: Number of results to return

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return await self._post(
            f"/v2/workspaces/{workspace_id}/conclusions/query",
            body=await async_maybe_transform(
                {
                    "query": query,
                    "distance": distance,
                    "filters": filters,
                    "top_k": top_k,
                },
                conclusion_query_params.ConclusionQueryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConclusionQueryResponse,
        )


class ConclusionsResourceWithRawResponse:
    def __init__(self, conclusions: ConclusionsResource) -> None:
        self._conclusions = conclusions

        self.create = to_raw_response_wrapper(
            conclusions.create,
        )
        self.list = to_raw_response_wrapper(
            conclusions.list,
        )
        self.delete = to_raw_response_wrapper(
            conclusions.delete,
        )
        self.query = to_raw_response_wrapper(
            conclusions.query,
        )


class AsyncConclusionsResourceWithRawResponse:
    def __init__(self, conclusions: AsyncConclusionsResource) -> None:
        self._conclusions = conclusions

        self.create = async_to_raw_response_wrapper(
            conclusions.create,
        )
        self.list = async_to_raw_response_wrapper(
            conclusions.list,
        )
        self.delete = async_to_raw_response_wrapper(
            conclusions.delete,
        )
        self.query = async_to_raw_response_wrapper(
            conclusions.query,
        )


class ConclusionsResourceWithStreamingResponse:
    def __init__(self, conclusions: ConclusionsResource) -> None:
        self._conclusions = conclusions

        self.create = to_streamed_response_wrapper(
            conclusions.create,
        )
        self.list = to_streamed_response_wrapper(
            conclusions.list,
        )
        self.delete = to_streamed_response_wrapper(
            conclusions.delete,
        )
        self.query = to_streamed_response_wrapper(
            conclusions.query,
        )


class AsyncConclusionsResourceWithStreamingResponse:
    def __init__(self, conclusions: AsyncConclusionsResource) -> None:
        self._conclusions = conclusions

        self.create = async_to_streamed_response_wrapper(
            conclusions.create,
        )
        self.list = async_to_streamed_response_wrapper(
            conclusions.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            conclusions.delete,
        )
        self.query = async_to_streamed_response_wrapper(
            conclusions.query,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .observation import Observation

__all__ = ["ObservationCreateResponse"]

ObservationCreateResponse: TypeAlias = List[Observation]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel
from .observation import Observation

__all__ = ["PageObservation"]


class PageObservation(BaseModel):
    items: List[Observation]

    page: int

    size: int

    pages: Optional[int] = None

    total: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["DeriverConfigurationParam"]


class DeriverConfigurationParam(TypedDict, total=False):
    custom_instructions: Optional[str]
    """TODO: currently unused.

    Custom instructions to use for the deriver on this workspace/session/message.
    """

    enabled: Optional[bool]
    """Whether to enable deriver functionality."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["SummaryConfigurationParam"]


class SummaryConfigurationParam(TypedDict, total=False):
    enabled: Optional[bool]
    """Whether to enable summary functionality."""

    messages_per_long_summary: Optional[int]
    """Number of messages per long summary.

    Must be positive, greater than or equal to 20, and greater than
    messages_per_short_summary.
    """

    messages_per_short_summary: Optional[int]
    """Number of messages per short summary.

    Must be positive, greater than or equal to 10, and less than
    messages_per_long_summary.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["PeerSetCardParams"]


class PeerSetCardParams(TypedDict, total=False):
    workspace_id: Required[str]
    """ID of the workspace"""

    peer_card: Required[SequenceNotStr[str]]
    """The peer card content to set"""

    target: Optional[str]
    """The peer whose card to set. If not provided, sets the observer's own card"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Required, TypedDict

from .workspace_configuration_param import WorkspaceConfigurationParam

__all__ = ["WorkspaceGetOrCreateParams"]


class WorkspaceGetOrCreateParams(TypedDict, total=False):
    id: Required[str]

    configuration: WorkspaceConfigurationParam
    """The set of options that can be in a workspace DB-level configuration dictionary.

    All fields are optional. Session-level configuration overrides workspace-level
    configuration, which overrides global configuration.
    """

    metadata: Dict[str, object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["PeerGetContextParams"]


class PeerGetContextParams(TypedDict, total=False):
    workspace_id: Required[str]
    """ID of the workspace"""

    include_most_derived: bool
    """Whether to include the most derived observations in the representation"""

    max_observations: Optional[int]
    """Maximum number of observations to include in the representation"""

    search_max_distance: Optional[float]
    """Only used if `search_query` is provided.

    Maximum distance for semantically relevant observations
    """

    search_query: Optional[str]
    """Optional query to curate the representation around semantic search results"""

    search_top_k: Optional[int]
    """Only used if `search_query` is provided.

    Number of semantic-search-retrieved observations to include
    """

    target: Optional[str]
    """The target peer to get context for.

    If not provided, returns the peer's own context (self-observation)
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing import Dict, Iterable, Optional

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncPage, AsyncPage
from ..._base_client import AsyncPaginator, make_request_options
from ...types.workspaces import observation_list_params, observation_query_params, observation_create_params
from ...types.workspaces.observation import Observation
from ...types.workspaces.conclusion_create_param import ConclusionCreateParam
from ...types.workspaces.observation_create_param import ObservationCreateParam
from ...types.workspaces.observation_query_response import ObservationQueryResponse
from ...types.workspaces.observation_create_response import ObservationCreateResponse

__all__ = ["ObservationsResource", "AsyncObservationsResource"]


class ObservationsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ObservationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/plastic-labs/honcho-python-core#accessing-raw-response-data-eg-headers
        """
        return ObservationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ObservationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/plastic-labs/honcho-python-core#with_streaming_response
        """
        return ObservationsResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    def create(
        self,
        workspace_id: str,
        *,
        conclusions: Iterable[ConclusionCreateParam],
        observations: Iterable[ObservationCreateParam],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObservationCreateResponse:
        """
        Create one or more observations.

        Creates observations (theory-of-mind facts) for the specified observer/observed
        peer pairs. Each observation must reference existing peers and a session within
        the workspace. Embeddings are automatically generated for semantic search.

        Maximum of 100 observations per request.

        Args:
          workspace_id: ID of the workspace

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return self._post(
            f"/v2/workspaces/{workspace_id}/observations",
            body=maybe_transform(
                {
                    "conclusions": conclusions,
                    "observations": observations,
                },
                observation_create_params.ObservationCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObservationCreateResponse,
        )

    @typing_extensions.deprecated("deprecated")
    def list(
        self,
        workspace_id: str,
        *,
        page: int | Omit = omit,
        reverse: Optional[bool] | Omit = omit,
        size: int | Omit = omit,
        filters: Optional[Dict[str, object]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncPage[Observation]:
        """List all observations using custom filters.

        Observations are listed by recency
        unless `reverse` is set to `true`.

        Observations can be filtered by session_id, observer_id and observed_id using
        the filters parameter.

        Args:
          workspace_id: ID of the workspace

          page: Page number

          reverse: Whether to reverse the order of results

          size: Page size

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return self._get_api_list(
            f"/v2/workspaces/{workspace_id}/observations/list",
            page=SyncPage[Observation],
            body=maybe_transform({"filters": filters}, observation_list_params.ObservationListParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "reverse": reverse,
                        "size": size,
                    },
                    observation_list_params.ObservationListParams,
                ),
            ),
            model=Observation,
            method="post",
        )

    @typing_extensions.deprecated("deprecated")
    def delete(
        self,
        observation_id: str,
        *,
        workspace_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Delete a specific observation.

        This permanently deletes the observation (document) from the theory-of-mind
        system. This action cannot be undone.

        Args:
          workspace_id: ID of the workspace

          observation_id: ID of the observation to delete

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        if not observation_id:
            raise ValueError(f"Expected a non-empty value for `observation_id` but received {observation_id!r}")
        return self._delete(
            f"/v2/workspaces/{workspace_id}/observations/{observation_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    @typing_extensions.deprecated("deprecated")
    def query(
        self,
        workspace_id: str,
        *,
        query: str,
        distance: Optional[float] | Omit = omit,
        filters: Optional[Dict[str, object]] | Omit = omit,
        top_k: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObservationQueryResponse:
        """
        Query observations using semantic search.

        Performs vector similarity search on observations to find semantically relevant
        results. Observer and observed are required for semantic search and must be
        provided in filters.

        Args:
          workspace_id: ID of the workspace

          query: Semantic search query

          distance: Maximum cosine distance threshold for results

          filters: Additional filters to apply

          top_k: Number of results to return

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return self._post(
            f"/v2/workspaces/{workspace_id}/observations/query",
            body=maybe_transform(
                {
                    "query": query,
                    "distance": distance,
                    "filters": filters,
                    "top_k": top_k,
                },
                observation_query_params.ObservationQueryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObservationQueryResponse,
        )


class AsyncObservationsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncObservationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/plastic-labs/honcho-python-core#accessing-raw-response-data-eg-headers
        """
        return AsyncObservationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncObservationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/plastic-labs/honcho-python-core#with_streaming_response
        """
        return AsyncObservationsResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    async def create(
        self,
        workspace_id: str,
        *,
        conclusions: Iterable[ConclusionCreateParam],
        observations: Iterable[ObservationCreateParam],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObservationCreateResponse:
        """
        Create one or more observations.

        Creates observations (theory-of-mind facts) for the specified observer/observed
        peer pairs. Each observation must reference existing peers and a session within
        the workspace. Embeddings are automatically generated for semantic search.

        Maximum of 100 observations per request.

        Args:
          workspace_id: ID of the workspace

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return await self._post(
            f"/v2/workspaces/{workspace_id}/observations",
            body=await async_maybe_transform(
                {
                    "conclusions": conclusions,
                    "observations": observations,
                },
                observation_create_params.ObservationCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObservationCreateResponse,
        )

    @typing_extensions.deprecated("deprecated")
    def list(
        self,
        workspace_id: str,
        *,
        page: int | Omit = omit,
        reverse: Optional[bool] | Omit = omit,
        size: int | Omit = omit,
        filters: Optional[Dict[str, object]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[Observation, AsyncPage[Observation]]:
        """List all observations using custom filters.

        Observations are listed by recency
        unless `reverse` is set to `true`.

        Observations can be filtered by session_id, observer_id and observed_id using
        the filters parameter.

        Args:
          workspace_id: ID of the workspace

          page: Page number

          reverse: Whether to reverse the order of results

          size: Page size

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return self._get_api_list(
            f"/v2/workspaces/{workspace_id}/observations/list",
            page=AsyncPage[Observation],
            body=maybe_transform({"filters": filters}, observation_list_params.ObservationListParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "reverse": reverse,
                        "size": size,
                    },
                    observation_list_params.ObservationListParams,
                ),
            ),
            model=Observation,
            method="post",
        )

    @typing_extensions.deprecated("deprecated")
    async def delete(
        self,
        observation_id: str,
        *,
        workspace_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Delete a specific observation.

        This permanently deletes the observation (document) from the theory-of-mind
        system. This action cannot be undone.

        Args:
          workspace_id: ID of the workspace

          observation_id: ID of the observation to delete

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        if not observation_id:
            raise ValueError(f"Expected a non-empty value for `observation_id` but received {observation_id!r}")
        return await self._delete(
            f"/v2/workspaces/{workspace_id}/observations/{observation_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    @typing_extensions.deprecated("deprecated")
    async def query(
        self,
        workspace_id: str,
        *,
        query: str,
        distance: Optional[float] | Omit = omit,
        filters: Optional[Dict[str, object]] | Omit = omit,
        top_k: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObservationQueryResponse:
        """
        Query observations using semantic search.

        Performs vector similarity search on observations to find semantically relevant
        results. Observer and observed are required for semantic search and must be
        provided in filters.

        Args:
          workspace_id: ID of the workspace

          query: Semantic search query

          distance: Maximum cosine distance threshold for results

          filters: Additional filters to apply

          top_k: Number of results to return

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_id:
            raise ValueError(f"Expected a non-empty value for `workspace_id` but received {workspace_id!r}")
        return await self._post(
            f"/v2/workspaces/{workspace_id}/observations/query",
            body=await async_maybe_transform(
                {
                    "query": query,
                    "distance": distance,
                    "filters": filters,
                    "top_k": top_k,
                },
                observation_query_params.ObservationQueryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObservationQueryResponse,
        )


class ObservationsResourceWithRawResponse:
    def __init__(self, observations: ObservationsResource) -> None:
        self._observations = observations

        self.create = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                observations.create,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                observations.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                observations.delete,  # pyright: ignore[reportDeprecated],
            )
        )
        self.query = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                observations.query,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncObservationsResourceWithRawResponse:
    def __init__(self, observations: AsyncObservationsResource) -> None:
        self._observations = observations

        self.create = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                observations.create,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                observations.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                observations.delete,  # pyright: ignore[reportDeprecated],
            )
        )
        self.query = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                observations.query,  # pyright: ignore[reportDeprecated],
            )
        )


class ObservationsResourceWithStreamingResponse:
    def __init__(self, observations: ObservationsResource) -> None:
        self._observations = observations

        self.create = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                observations.create,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                observations.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                observations.delete,  # pyright: ignore[reportDeprecated],
            )
        )
        self.query = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                observations.query,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncObservationsResourceWithStreamingResponse:
    def __init__(self, observations: AsyncObservationsResource) -> None:
        self._observations = observations

        self.create = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                observations.create,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                observations.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                observations.delete,  # pyright: ignore[reportDeprecated],
            )
        )
        self.query = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                observations.query,  # pyright: ignore[reportDeprecated],
            )
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["PeerWorkingRepresentationParams"]


class PeerWorkingRepresentationParams(TypedDict, total=False):
    workspace_id: Required[str]
    """ID of the workspace"""

    include_most_derived: Optional[bool]
    """Only used if `search_query` is provided.

    Whether to include the most derived observations in the representation
    """

    max_observations: Optional[int]
    """Only used if `search_query` is provided.

    Maximum number of observations to include in the representation
    """

    search_max_distance: Optional[float]
    """Only used if `search_query` is provided.

    Maximum distance to search for semantically relevant observations
    """

    search_query: Optional[str]
    """Optional input to curate the representation around semantic search results"""

    search_top_k: Optional[int]
    """Only used if `search_query` is provided.

    Number of semantic-search-retrieved observations to include in the
    representation
    """

    session_id: Optional[str]
    """Get the working representation within this session"""

    target: Optional[str]
    """
    Optional peer ID to get the representation for, from the perspective of this
    peer
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

from .conclusion_create_param import ConclusionCreateParam

__all__ = ["ConclusionCreateParams"]


class ConclusionCreateParams(TypedDict, total=False):
    conclusions: Required[Iterable[ConclusionCreateParam]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Optional
from typing_extensions import TypeAlias, TypedDict

from ..dream_configuration_param import DreamConfigurationParam
from ..deriver_configuration_param import DeriverConfigurationParam
from ..summary_configuration_param import SummaryConfigurationParam
from ..peer_card_configuration_param import PeerCardConfigurationParam

__all__ = ["SessionConfigurationParam"]


class SessionConfigurationParamTyped(TypedDict, total=False):
    """The set of options that can be in a session DB-level configuration dictionary.

    All fields are optional. Session-level configuration overrides workspace-level configuration, which overrides global configuration.
    """

    deriver: Optional[DeriverConfigurationParam]
    """Configuration for deriver functionality."""

    dream: Optional[DreamConfigurationParam]
    """Configuration for dream functionality.

    If deriver is disabled, dreams will also be disabled and these settings will be
    ignored.
    """

    peer_card: Optional[PeerCardConfigurationParam]
    """Configuration for peer card functionality.

    If deriver is disabled, peer cards will also be disabled and these settings will
    be ignored.
    """

    summary: Optional[SummaryConfigurationParam]
    """Configuration for summary functionality."""


SessionConfigurationParam: TypeAlias = Union[SessionConfigurationParamTyped, Dict[str, object]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

from ...._types import FileTypes

__all__ = ["MessageUploadParams"]


class MessageUploadParams(TypedDict, total=False):
    workspace_id: Required[str]

    file: Required[FileTypes]

    peer_id: Required[str]

    configuration: Optional[str]

    created_at: Optional[str]

    metadata: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .conclusion import Conclusion

__all__ = ["ConclusionQueryResponse"]

ConclusionQueryResponse: TypeAlias = List[Conclusion]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["DreamConfigurationParam"]


class DreamConfigurationParam(TypedDict, total=False):
    enabled: Optional[bool]
    """Whether to enable dream functionality.

    If deriver is disabled, dreams will also be disabled and this setting will be
    ignored.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Optional
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo
from ...deriver_configuration_param import DeriverConfigurationParam
from ...peer_card_configuration_param import PeerCardConfigurationParam

__all__ = ["MessageCreateParam", "Configuration"]


class Configuration(TypedDict, total=False):
    """The set of options that can be in a message DB-level configuration dictionary.

    All fields are optional. Message-level configuration overrides all other configurations.
    """

    deriver: Optional[DeriverConfigurationParam]
    """Configuration for deriver functionality."""

    peer_card: Optional[PeerCardConfigurationParam]
    """Configuration for peer card functionality.

    If deriver is disabled, peer cards will also be disabled and these settings will
    be ignored.
    """


class MessageCreateParam(TypedDict, total=False):
    content: Required[str]

    peer_id: Required[str]

    configuration: Optional[Configuration]
    """The set of options that can be in a message DB-level configuration dictionary.

    All fields are optional. Message-level configuration overrides all other
    configurations.
    """

    created_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]

    metadata: Optional[Dict[str, object]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .summary import Summary
from ..._models import BaseModel
from .sessions.message import Message

__all__ = [
    "SessionGetContextResponse",
    "PeerRepresentation",
    "PeerRepresentationDeductive",
    "PeerRepresentationExplicit",
]


class PeerRepresentationDeductive(BaseModel):
    """Deductive observation with multiple premises and one conclusion, plus metadata."""

    conclusion: str
    """The deductive conclusion"""

    created_at: datetime

    message_ids: List[int]

    session_name: str

    premises: Optional[List[str]] = None
    """Supporting premises or evidence for this conclusion"""


class PeerRepresentationExplicit(BaseModel):
    """Explicit observation with content and metadata."""

    content: str
    """The explicit observation"""

    created_at: datetime

    message_ids: List[int]

    session_name: str


class PeerRepresentation(BaseModel):
    """
    A Representation is a traversable and diffable map of observations.
    At the base, we have a list of explicit observations, derived from a peer's messages.

    From there, deductive observations can be made by establishing logical relationships between explicit observations.

    In the future, we can add more levels of reasoning on top of these.

    All of a peer's observations are stored as documents in a collection. These documents can be queried in various ways
    to produce this Representation object.

    Additionally, a "working representation" is a version of this data structure representing the most recent observations
    within a single session.

    A representation can have a maximum number of observations, which is applied individually to each level of reasoning.
    If a maximum is set, observations are added and removed in FIFO order.
    """

    deductive: Optional[List[PeerRepresentationDeductive]] = None
    """
    Conclusions that MUST be true given explicit facts and premises - strict logical
    necessities. Each deduction should have premises and a single conclusion.
    """

    explicit: Optional[List[PeerRepresentationExplicit]] = None
    """
    Facts LITERALLY stated by the user - direct quotes or clear paraphrases only, no
    interpretation or inference. Example: ['The user is 25 years old', 'The user has
    a dog']
    """


class SessionGetContextResponse(BaseModel):
    id: str

    messages: List[Message]

    peer_card: Optional[List[str]] = None
    """The peer card, if context is requested from a specific perspective"""

    peer_representation: Optional[PeerRepresentation] = None
    """
    A Representation is a traversable and diffable map of observations. At the base,
    we have a list of explicit observations, derived from a peer's messages.

    From there, deductive observations can be made by establishing logical
    relationships between explicit observations.

    In the future, we can add more levels of reasoning on top of these.

    All of a peer's observations are stored as documents in a collection. These
    documents can be queried in various ways to produce this Representation object.

    Additionally, a "working representation" is a version of this data structure
    representing the most recent observations within a single session.

    A representation can have a maximum number of observations, which is applied
    individually to each level of reasoning. If a maximum is set, observations are
    added and removed in FIFO order.
    """

    summary: Optional[Summary] = None
    """The summary if available"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["ConclusionCreateParam"]


class ConclusionCreateParam(TypedDict, total=False):
    """Schema for creating a single conclusion."""

    content: Required[str]

    observed_id: Required[str]
    """The peer the conclusion is about"""

    observer_id: Required[str]
    """The peer making the conclusion"""

    session_id: Required[str]
    """The session this conclusion relates to"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from datetime import datetime

from ..._models import BaseModel

__all__ = ["Conclusion"]


class Conclusion(BaseModel):
    """Conclusion response - external view of a document."""

    id: str

    content: str

    created_at: datetime

    observed_id: str
    """The peer the conclusion is about"""

    observer_id: str
    """The peer who made the conclusion"""

    session_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Required, TypedDict

from .session_configuration_param import SessionConfigurationParam

__all__ = ["SessionUpdateParams"]


class SessionUpdateParams(TypedDict, total=False):
    workspace_id: Required[str]
    """ID of the workspace"""

    configuration: Optional[SessionConfigurationParam]
    """The set of options that can be in a session DB-level configuration dictionary.

    All fields are optional. Session-level configuration overrides workspace-level
    configuration, which overrides global configuration.
    """

    metadata: Optional[Dict[str, object]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from honcho_core import Honcho, AsyncHoncho
from tests.utils import assert_matches_type
from honcho_core.pagination import SyncPage, AsyncPage
from honcho_core.types.workspaces import (
    Observation,
    ObservationQueryResponse,
    ObservationCreateResponse,
)

# pyright: reportDeprecated=false

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestObservations:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = client.workspaces.observations.create(
                workspace_id="workspace_id",
                conclusions=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
                observations=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
            )

        assert_matches_type(ObservationCreateResponse, observation, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.workspaces.observations.with_raw_response.create(
                workspace_id="workspace_id",
                conclusions=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
                observations=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        observation = response.parse()
        assert_matches_type(ObservationCreateResponse, observation, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            with client.workspaces.observations.with_streaming_response.create(
                workspace_id="workspace_id",
                conclusions=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
                observations=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                observation = response.parse()
                assert_matches_type(ObservationCreateResponse, observation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_id` but received ''"):
                client.workspaces.observations.with_raw_response.create(
                    workspace_id="",
                    conclusions=[
                        {
                            "content": "x",
                            "observed_id": "observed_id",
                            "observer_id": "observer_id",
                            "session_id": "session_id",
                        }
                    ],
                    observations=[
                        {
                            "content": "x",
                            "observed_id": "observed_id",
                            "observer_id": "observer_id",
                            "session_id": "session_id",
                        }
                    ],
                )

    @parametrize
    def test_method_list(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = client.workspaces.observations.list(
                workspace_id="workspace_id",
            )

        assert_matches_type(SyncPage[Observation], observation, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = client.workspaces.observations.list(
                workspace_id="workspace_id",
                page=1,
                reverse=True,
                size=1,
                filters={"foo": "bar"},
            )

        assert_matches_type(SyncPage[Observation], observation, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.workspaces.observations.with_raw_response.list(
                workspace_id="workspace_id",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        observation = response.parse()
        assert_matches_type(SyncPage[Observation], observation, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            with client.workspaces.observations.with_streaming_response.list(
                workspace_id="workspace_id",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                observation = response.parse()
                assert_matches_type(SyncPage[Observation], observation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_id` but received ''"):
                client.workspaces.observations.with_raw_response.list(
                    workspace_id="",
                )

    @parametrize
    def test_method_delete(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = client.workspaces.observations.delete(
                observation_id="observation_id",
                workspace_id="workspace_id",
            )

        assert_matches_type(object, observation, path=["response"])

    @parametrize
    def test_raw_response_delete(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.workspaces.observations.with_raw_response.delete(
                observation_id="observation_id",
                workspace_id="workspace_id",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        observation = response.parse()
        assert_matches_type(object, observation, path=["response"])

    @parametrize
    def test_streaming_response_delete(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            with client.workspaces.observations.with_streaming_response.delete(
                observation_id="observation_id",
                workspace_id="workspace_id",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                observation = response.parse()
                assert_matches_type(object, observation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_id` but received ''"):
                client.workspaces.observations.with_raw_response.delete(
                    observation_id="observation_id",
                    workspace_id="",
                )

            with pytest.raises(ValueError, match=r"Expected a non-empty value for `observation_id` but received ''"):
                client.workspaces.observations.with_raw_response.delete(
                    observation_id="",
                    workspace_id="workspace_id",
                )

    @parametrize
    def test_method_query(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = client.workspaces.observations.query(
                workspace_id="workspace_id",
                query="query",
            )

        assert_matches_type(ObservationQueryResponse, observation, path=["response"])

    @parametrize
    def test_method_query_with_all_params(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = client.workspaces.observations.query(
                workspace_id="workspace_id",
                query="query",
                distance=0,
                filters={"foo": "bar"},
                top_k=1,
            )

        assert_matches_type(ObservationQueryResponse, observation, path=["response"])

    @parametrize
    def test_raw_response_query(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.workspaces.observations.with_raw_response.query(
                workspace_id="workspace_id",
                query="query",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        observation = response.parse()
        assert_matches_type(ObservationQueryResponse, observation, path=["response"])

    @parametrize
    def test_streaming_response_query(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            with client.workspaces.observations.with_streaming_response.query(
                workspace_id="workspace_id",
                query="query",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                observation = response.parse()
                assert_matches_type(ObservationQueryResponse, observation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_query(self, client: Honcho) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_id` but received ''"):
                client.workspaces.observations.with_raw_response.query(
                    workspace_id="",
                    query="query",
                )


class TestAsyncObservations:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = await async_client.workspaces.observations.create(
                workspace_id="workspace_id",
                conclusions=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
                observations=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
            )

        assert_matches_type(ObservationCreateResponse, observation, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.workspaces.observations.with_raw_response.create(
                workspace_id="workspace_id",
                conclusions=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
                observations=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        observation = await response.parse()
        assert_matches_type(ObservationCreateResponse, observation, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.workspaces.observations.with_streaming_response.create(
                workspace_id="workspace_id",
                conclusions=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
                observations=[
                    {
                        "content": "x",
                        "observed_id": "observed_id",
                        "observer_id": "observer_id",
                        "session_id": "session_id",
                    }
                ],
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                observation = await response.parse()
                assert_matches_type(ObservationCreateResponse, observation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_id` but received ''"):
                await async_client.workspaces.observations.with_raw_response.create(
                    workspace_id="",
                    conclusions=[
                        {
                            "content": "x",
                            "observed_id": "observed_id",
                            "observer_id": "observer_id",
                            "session_id": "session_id",
                        }
                    ],
                    observations=[
                        {
                            "content": "x",
                            "observed_id": "observed_id",
                            "observer_id": "observer_id",
                            "session_id": "session_id",
                        }
                    ],
                )

    @parametrize
    async def test_method_list(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = await async_client.workspaces.observations.list(
                workspace_id="workspace_id",
            )

        assert_matches_type(AsyncPage[Observation], observation, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = await async_client.workspaces.observations.list(
                workspace_id="workspace_id",
                page=1,
                reverse=True,
                size=1,
                filters={"foo": "bar"},
            )

        assert_matches_type(AsyncPage[Observation], observation, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.workspaces.observations.with_raw_response.list(
                workspace_id="workspace_id",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        observation = await response.parse()
        assert_matches_type(AsyncPage[Observation], observation, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.workspaces.observations.with_streaming_response.list(
                workspace_id="workspace_id",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                observation = await response.parse()
                assert_matches_type(AsyncPage[Observation], observation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_id` but received ''"):
                await async_client.workspaces.observations.with_raw_response.list(
                    workspace_id="",
                )

    @parametrize
    async def test_method_delete(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = await async_client.workspaces.observations.delete(
                observation_id="observation_id",
                workspace_id="workspace_id",
            )

        assert_matches_type(object, observation, path=["response"])

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.workspaces.observations.with_raw_response.delete(
                observation_id="observation_id",
                workspace_id="workspace_id",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        observation = await response.parse()
        assert_matches_type(object, observation, path=["response"])

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.workspaces.observations.with_streaming_response.delete(
                observation_id="observation_id",
                workspace_id="workspace_id",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                observation = await response.parse()
                assert_matches_type(object, observation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_id` but received ''"):
                await async_client.workspaces.observations.with_raw_response.delete(
                    observation_id="observation_id",
                    workspace_id="",
                )

            with pytest.raises(ValueError, match=r"Expected a non-empty value for `observation_id` but received ''"):
                await async_client.workspaces.observations.with_raw_response.delete(
                    observation_id="",
                    workspace_id="workspace_id",
                )

    @parametrize
    async def test_method_query(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = await async_client.workspaces.observations.query(
                workspace_id="workspace_id",
                query="query",
            )

        assert_matches_type(ObservationQueryResponse, observation, path=["response"])

    @parametrize
    async def test_method_query_with_all_params(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            observation = await async_client.workspaces.observations.query(
                workspace_id="workspace_id",
                query="query",
                distance=0,
                filters={"foo": "bar"},
                top_k=1,
            )

        assert_matches_type(ObservationQueryResponse, observation, path=["response"])

    @parametrize
    async def test_raw_response_query(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.workspaces.observations.with_raw_response.query(
                workspace_id="workspace_id",
                query="query",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        observation = await response.parse()
        assert_matches_type(ObservationQueryResponse, observation, path=["response"])

    @parametrize
    async def test_streaming_response_query(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.workspaces.observations.with_streaming_response.query(
                workspace_id="workspace_id",
                query="query",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                observation = await response.parse()
                assert_matches_type(ObservationQueryResponse, observation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_query(self, async_client: AsyncHoncho) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `workspace_id` but received ''"):
                await async_client.workspaces.observations.with_raw_response.query(
                    workspace_id="",
                    query="query",
                )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["PeerGetContextResponse", "Representation", "RepresentationDeductive", "RepresentationExplicit"]


class RepresentationDeductive(BaseModel):
    """Deductive observation with multiple premises and one conclusion, plus metadata."""

    conclusion: str
    """The deductive conclusion"""

    created_at: datetime

    message_ids: List[int]

    session_name: str

    premises: Optional[List[str]] = None
    """Supporting premises or evidence for this conclusion"""


class RepresentationExplicit(BaseModel):
    """Explicit observation with content and metadata."""

    content: str
    """The explicit observation"""

    created_at: datetime

    message_ids: List[int]

    session_name: str


class Representation(BaseModel):
    """
    A Representation is a traversable and diffable map of observations.
    At the base, we have a list of explicit observations, derived from a peer's messages.

    From there, deductive observations can be made by establishing logical relationships between explicit observations.

    In the future, we can add more levels of reasoning on top of these.

    All of a peer's observations are stored as documents in a collection. These documents can be queried in various ways
    to produce this Representation object.

    Additionally, a "working representation" is a version of this data structure representing the most recent observations
    within a single session.

    A representation can have a maximum number of observations, which is applied individually to each level of reasoning.
    If a maximum is set, observations are added and removed in FIFO order.
    """

    deductive: Optional[List[RepresentationDeductive]] = None
    """
    Conclusions that MUST be true given explicit facts and premises - strict logical
    necessities. Each deduction should have premises and a single conclusion.
    """

    explicit: Optional[List[RepresentationExplicit]] = None
    """
    Facts LITERALLY stated by the user - direct quotes or clear paraphrases only, no
    interpretation or inference. Example: ['The user is 25 years old', 'The user has
    a dog']
    """


class PeerGetContextResponse(BaseModel):
    """Context for a peer, including representation and peer card."""

    peer_id: str
    """The ID of the peer"""

    target_id: str
    """The ID of the target peer being observed"""

    peer_card: Optional[List[str]] = None
    """The peer card for the target peer from the observer's perspective"""

    representation: Optional[Representation] = None
    """
    A Representation is a traversable and diffable map of observations. At the base,
    we have a list of explicit observations, derived from a peer's messages.

    From there, deductive observations can be made by establishing logical
    relationships between explicit observations.

    In the future, we can add more levels of reasoning on top of these.

    All of a peer's observations are stored as documents in a collection. These
    documents can be queried in various ways to produce this Representation object.

    Additionally, a "working representation" is a version of this data structure
    representing the most recent observations within a single session.

    A representation can have a maximum number of observations, which is applied
    individually to each level of reasoning. If a maximum is set, observations are
    added and removed in FIFO order.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .summary import Summary
from ..._models import BaseModel

__all__ = ["SessionSummariesResponse"]


class SessionSummariesResponse(BaseModel):
    id: str

    long_summary: Optional[Summary] = None
    """The long summary if available"""

    short_summary: Optional[Summary] = None
    """The short summary if available"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .workspace import Workspace as Workspace
from .queue_status import QueueStatus as QueueStatus
from .deriver_status import DeriverStatus as DeriverStatus
from .key_create_params import KeyCreateParams as KeyCreateParams
from .workspace_list_params import WorkspaceListParams as WorkspaceListParams
from .workspace_search_params import WorkspaceSearchParams as WorkspaceSearchParams
from .workspace_update_params import WorkspaceUpdateParams as WorkspaceUpdateParams
from .dream_configuration_param import DreamConfigurationParam as DreamConfigurationParam
from .workspace_search_response import WorkspaceSearchResponse as WorkspaceSearchResponse
from .deriver_configuration_param import DeriverConfigurationParam as DeriverConfigurationParam
from .summary_configuration_param import SummaryConfigurationParam as SummaryConfigurationParam
from .peer_card_configuration_param import PeerCardConfigurationParam as PeerCardConfigurationParam
from .workspace_configuration_param import WorkspaceConfigurationParam as WorkspaceConfigurationParam
from .workspace_queue_status_params import WorkspaceQueueStatusParams as WorkspaceQueueStatusParams
from .workspace_get_or_create_params import WorkspaceGetOrCreateParams as WorkspaceGetOrCreateParams
from .workspace_trigger_dream_params import WorkspaceTriggerDreamParams as WorkspaceTriggerDreamParams
from .workspace_deriver_status_params import WorkspaceDeriverStatusParams as WorkspaceDeriverStatusParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel
from .conclusion import Conclusion

__all__ = ["PageConclusion"]


class PageConclusion(BaseModel):
    items: List[Conclusion]

    page: int

    size: int

    pages: Optional[int] = None

    total: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["SessionGetContextParams"]


class SessionGetContextParams(TypedDict, total=False):
    workspace_id: Required[str]
    """ID of the workspace"""

    include_most_derived: bool
    """Only used if `last_message` is provided.

    Whether to include the most derived observations in the representation
    """

    last_message: Optional[str]
    """The most recent message, used to fetch semantically relevant observations"""

    limit_to_session: bool
    """Only used if `last_message` is provided.

    Whether to limit the representation to the session (as opposed to everything
    known about the target peer)
    """

    max_observations: Optional[int]
    """Only used if `last_message` is provided.

    The maximum number of observations to include in the representation
    """

    peer_perspective: Optional[str]
    """A peer to get context for.

    If given, response will attempt to include representation and card from the
    perspective of that peer. Must be provided with `peer_target`.
    """

    peer_target: Optional[str]
    """The target of the perspective.

    If given without `peer_perspective`, will get the Honcho-level representation
    and peer card for this peer. If given with `peer_perspective`, will get the
    representation and card for this peer _from the perspective of that peer_.
    """

    search_max_distance: Optional[float]
    """Only used if `last_message` is provided.

    The maximum distance to search for semantically relevant observations
    """

    search_top_k: Optional[int]
    """Only used if `last_message` is provided.

    The number of semantic-search-retrieved observations to include in the
    representation
    """

    summary: bool
    """Whether or not to include a summary _if_ one is available for the session"""

    tokens: Optional[int]
    """Number of tokens to use for the context.

    Includes summary if set to true. Includes representation and peer card if they
    are included in the response. If not provided, the context will be exhaustive
    (within 100000 tokens)
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

from .conclusion_create_param import ConclusionCreateParam
from .observation_create_param import ObservationCreateParam

__all__ = ["ObservationCreateParams"]


class ObservationCreateParams(TypedDict, total=False):
    conclusions: Required[Iterable[ConclusionCreateParam]]

    observations: Required[Iterable[ObservationCreateParam]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["WorkspaceTriggerDreamParams"]


class WorkspaceTriggerDreamParams(TypedDict, total=False):
    dream_type: Required[Literal["consolidate", "agent"]]
    """Type of dream to trigger"""

    observer: Required[str]
    """Observer peer name"""

    observed: Optional[str]
    """Observed peer name (defaults to observer if not specified)"""
